@@ -23,7 +23,6 @@ class JourneyReply;
 class JourneySection;
 class Manager;
 class OnboardStatus;
-class StopoverReply;
 }
 
 class KNotification;
@@ -73,9 +72,11 @@ public:
     /** Trigger disruption notification, only exposed for testing here. */
     Q_INVOKABLE void showNotification(const QString &resId);
 
-public Q_SLOTS:
     /** Checks all applicable elements for updates. */
-    void checkForUpdates();
+    Q_INVOKABLE void checkForUpdates();
+
+    /** Checks the given batches for updates. */
+    Q_INVOKABLE void checkForUpdates(const QStringList &batchIds);
 
 Q_SIGNALS:
     void arrivalUpdated(const QString &resId);
@@ -91,11 +92,8 @@ private:
     void batchRemoved(const QString &resId);
 
     void checkReservation(const QVariant &res, const QString &resId);
-    void stopoverQueryFinished(KPublicTransport::StopoverReply *reply, LiveData::Type type, const QString &resId);
-    void stopoverQueryFinished(std::vector<KPublicTransport::Stopover> &&result, LiveData::Type type, const QString &resId);
-    void journeyQueryFinished(KPublicTransport::JourneyReply *reply, const QString &resId);
+    void tripQueryFailed(const QString &resId);
 
-    void updateStopoverData(const KPublicTransport::Stopover &stop, LiveData::Type type, const QString &resId, const QVariant &res);
     void updateJourneyData(const KPublicTransport::JourneySection &journey, const QString &resId, const QVariant &res);
 
     void showNotification(const QString &resId, const LiveData &ld);
@@ -116,6 +114,8 @@ private:
     void poll();
     /// @p force will bypass the check if the data is still up to date
     void pollForUpdates(bool force);
+    void pollBatchForUpdates(const QString &batchId, bool force);
+    void clearArrived();
     int nextPollTime() const;
     int nextPollTimeForReservation(const QString &resId) const;
 
