@@ -51,11 +51,6 @@ StatisticsModel::StatisticsModel(QObject *parent)
 
 StatisticsModel::~StatisticsModel() = default;
 
-ReservationManager *StatisticsModel::reservationManager() const
-{
-    return m_resMgr;
-}
-
 void StatisticsModel::setReservationManager(ReservationManager *resMgr)
 {
     if (m_resMgr == resMgr) {
@@ -63,14 +58,11 @@ void StatisticsModel::setReservationManager(ReservationManager *resMgr)
     }
     m_resMgr = resMgr;
     connect(m_resMgr, &ReservationManager::batchAdded, this, &StatisticsModel::recompute);
+    connect(m_resMgr, &ReservationManager::batchContentChanged, this, &StatisticsModel::recompute);
+    connect(m_resMgr, &ReservationManager::batchRemoved, this, &StatisticsModel::recompute);
     Q_EMIT setupChanged();
 }
 
-TripGroupManager *StatisticsModel::tripGroupManager() const
-{
-    return m_tripGroupMgr;
-}
-
 void StatisticsModel::setTripGroupManager(TripGroupManager *tripGroupMgr)
 {
     if (m_tripGroupMgr == tripGroupMgr) {
@@ -78,6 +70,7 @@ void StatisticsModel::setTripGroupManager(TripGroupManager *tripGroupMgr)
     }
     m_tripGroupMgr = tripGroupMgr;
     connect(m_tripGroupMgr, &TripGroupManager::tripGroupAdded, this, &StatisticsModel::recompute);
+    connect(m_tripGroupMgr, &TripGroupManager::tripGroupRemoved, this, &StatisticsModel::recompute);
     Q_EMIT setupChanged();
 }
 
@@ -88,6 +81,8 @@ void StatisticsModel::setTransferManager(TransferManager *transferMgr)
     }
     m_transferMgr = transferMgr;
     connect(m_transferMgr, &TransferManager::transferAdded, this, &StatisticsModel::recompute);
+    connect(m_transferMgr, &TransferManager::transferChanged, this, &StatisticsModel::recompute);
+    connect(m_transferMgr, &TransferManager::transferRemoved, this, &StatisticsModel::recompute);
     Q_EMIT setupChanged();
 }
 
@@ -109,7 +104,7 @@ StatisticsItem StatisticsModel::totalCount() const
 
 StatisticsItem StatisticsModel::totalDistance() const
 {
-    return StatisticsItem(i18n("Distance"), Localizer::formatDistance(m_statData[Total][Distance]), trend(Total, Distance));
+    return StatisticsItem(i18n("Distance"), formatDistance(m_statData[Total][Distance]), trend(Total, Distance));
 }
 
 StatisticsItem StatisticsModel::totalNights() const
@@ -142,7 +137,7 @@ StatisticsItem StatisticsModel::flightCount() const
 
 StatisticsItem StatisticsModel::flightDistance() const
 {
-    return StatisticsItem(i18n("Distance"), Localizer::formatDistance(m_statData[Flight][Distance]), trend(Flight, Distance), m_hasData[Flight]);
+    return StatisticsItem(i18n("Distance"), formatDistance(m_statData[Flight][Distance]), trend(Flight, Distance), m_hasData[Flight]);
 }
 
 StatisticsItem StatisticsModel::flightCO2() const
@@ -157,7 +152,7 @@ StatisticsItem StatisticsModel::trainCount() const
 
 StatisticsItem StatisticsModel::trainDistance() const
 {
-    return StatisticsItem(i18n("Distance"), Localizer::formatDistance(m_statData[Train][Distance]), trend(Train, Distance), m_hasData[Train]);
+    return StatisticsItem(i18n("Distance"), formatDistance(m_statData[Train][Distance]), trend(Train, Distance), m_hasData[Train]);
 }
 
 StatisticsItem StatisticsModel::trainCO2() const
@@ -172,7 +167,7 @@ StatisticsItem StatisticsModel::busCount() const
 
 StatisticsItem StatisticsModel::busDistance() const
 {
-    return StatisticsItem(i18n("Distance"), Localizer::formatDistance(m_statData[Bus][Distance]), trend(Bus, Distance), m_hasData[Bus]);
+    return StatisticsItem(i18n("Distance"), formatDistance(m_statData[Bus][Distance]), trend(Bus, Distance), m_hasData[Bus]);
 }
 
 StatisticsItem StatisticsModel::busCO2() const
@@ -187,7 +182,7 @@ StatisticsItem StatisticsModel::carCount() const
 
 StatisticsItem StatisticsModel::carDistance() const
 {
-    return StatisticsItem(i18n("Distance"), Localizer::formatDistance(m_statData[Car][Distance]), trend(Car, Distance), m_hasData[Car]);
+    return StatisticsItem(i18n("Distance"), formatDistance(m_statData[Car][Distance]), trend(Car, Distance), m_hasData[Car]);
 }
 
 StatisticsItem StatisticsModel::carCO2() const
@@ -202,7 +197,7 @@ StatisticsItem StatisticsModel::boatCount() const
 
 StatisticsItem StatisticsModel::boatDistance() const
 {
-    return StatisticsItem(i18n("Distance"), Localizer::formatDistance(m_statData[Boat][Distance]), trend(Boat, Distance), m_hasData[Boat]);
+    return StatisticsItem(i18n("Distance"), formatDistance(m_statData[Boat][Distance]), trend(Boat, Distance), m_hasData[Boat]);
 }
 
 StatisticsItem StatisticsModel::boatCO2() const
@@ -260,12 +255,12 @@ void StatisticsModel::computeStats(const QString &resId, const QVariant &res, in
     }
 
     statData[type][TripCount]++;
-    statData[type][Distance] += dist;
-    statData[type][CO2] += co2;
+    statData[type][Distance] += (int)std::round(dist);
+    statData[type][CO2] += (int)std::round(co2);
 
     statData[Total][TripCount]++;
-    statData[Total][Distance] += dist;
-    statData[Total][CO2] += co2;
+    statData[Total][Distance] += (int)std::round(dist);
+    statData[Total][CO2] += (int)std::round(co2);
 }
 
 void StatisticsModel::computeStats(const KPublicTransport::Journey &journey, int (&statData)[AGGREGATE_TYPE_COUNT][STAT_TYPE_COUNT])
@@ -335,8 +330,8 @@ void StatisticsModel::computeStats(const KPublicTransport::Journey &journey, int
 
 void StatisticsModel::recompute()
 {
-    memset(m_statData, 0, AGGREGATE_TYPE_COUNT * STAT_TYPE_COUNT * sizeof(int));
-    memset(m_prevStatData, 0, AGGREGATE_TYPE_COUNT * STAT_TYPE_COUNT * sizeof(int));
+    memset(m_statData, 0, (std::size_t)qToUnderlying(AGGREGATE_TYPE_COUNT) * qToUnderlying(STAT_TYPE_COUNT) * sizeof(int));
+    memset(m_prevStatData, 0, (std::size_t)qToUnderlying(AGGREGATE_TYPE_COUNT) * qToUnderlying(STAT_TYPE_COUNT) * sizeof(int));
     memset(m_hasData, 0, AGGREGATE_TYPE_COUNT * sizeof(bool));
     m_hasData[Total] = true;
     m_hotelCount = 0;
@@ -383,9 +378,9 @@ void StatisticsModel::recompute()
         } else if (JsonLd::isA<LodgingReservation>(res)) {
             const auto hotel = res.value<LodgingReservation>();
             if (isPrev) {
-                m_prevHotelCount += hotel.checkinTime().daysTo(hotel.checkoutTime());
+                m_prevHotelCount += (int)hotel.checkinTime().daysTo(hotel.checkoutTime());
             } else {
-                m_hotelCount += hotel.checkinTime().daysTo(hotel.checkoutTime());
+                m_hotelCount += (int)hotel.checkinTime().daysTo(hotel.checkoutTime());
             }
         }
 
@@ -412,8 +407,8 @@ void StatisticsModel::recompute()
         }
     }
 
-    m_tripGroupCount = tripGroups.size();
-    m_prevTripGroupCount = prevTripGroups.size();
+    m_tripGroupCount = (int)tripGroups.size();
+    m_prevTripGroupCount = (int)prevTripGroups.size();
 
     Q_EMIT changed();
 }
@@ -428,6 +423,11 @@ bool StatisticsModel::isRelevantTripGroup(const QString &tgId) const
     });
 }
 
+QString StatisticsModel::formatDistance(int dist) const
+{
+    return m_formatter.formatDistance(dist, m_distanceFormat);
+}
+
 StatisticsItem::Trend StatisticsModel::trend(int current, int prev) const
 {
     if (!m_begin.isValid() || !m_end.isValid()) {
